"""View package for analysis UI components."""

from .terminal import format_analysis, prompt_user, get_option_selection

__all__ = [
    'format_analysis',
    'prompt_user',
    'get_option_selection'
]